Welcome to scikit-network's documentation!
==========================================

.. include:: readme.rst

.. toctree::
   :maxdepth: 2
   :caption: Installation & Reference

   installation
   reference/index


.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   tutorials/getting_started
   tutorials/data/index
   tutorials/topology/index
   tutorials/path/index
   tutorials/clustering/index
   tutorials/hierarchy/index
   tutorials/ranking/index
   tutorials/classification/index
   tutorials/embedding/index
   tutorials/linkpred/index
   tutorials/utils/index
   tutorials/visualization/index

.. toctree::
   :maxdepth: 1
   :caption: About

   contributing
   authors
   history
   genindex
   glossary

